Index: Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerHelper.cs
===================================================================
diff -u -r738617f07027419f558043bd50caf8e53663dd0d -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerHelper.cs (.../SoilLayerHelper.cs) (revision 738617f07027419f558043bd50caf8e53663dd0d)
+++ Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerHelper.cs (.../SoilLayerHelper.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -127,7 +127,7 @@
}
if (properties.AbovePhreaticLevelCoefficientOfVariation.HasValue)
{
- soilLayer.AbovePhreaticLevelDeviation = properties.AbovePhreaticLevelCoefficientOfVariation.Value;
+ soilLayer.AbovePhreaticLevelCoefficientOfVariation = properties.AbovePhreaticLevelCoefficientOfVariation.Value;
}
if (properties.CohesionDistribution.HasValue)
{
@@ -143,7 +143,7 @@
}
if (properties.CohesionCoefficientOfVariation.HasValue)
{
- soilLayer.CohesionDeviation = properties.CohesionCoefficientOfVariation.Value;
+ soilLayer.CohesionCoefficientOfVariation = properties.CohesionCoefficientOfVariation.Value;
}
if (properties.FrictionAngleDistribution.HasValue)
{
@@ -159,7 +159,7 @@
}
if (properties.FrictionAngleCoefficientOfVariation.HasValue)
{
- soilLayer.FrictionAngleDeviation = properties.FrictionAngleCoefficientOfVariation.Value;
+ soilLayer.FrictionAngleCoefficientOfVariation = properties.FrictionAngleCoefficientOfVariation.Value;
}
if (properties.ShearStrengthRatioDistribution.HasValue)
{
@@ -175,7 +175,7 @@
}
if (properties.ShearStrengthRatioCoefficientOfVariation.HasValue)
{
- soilLayer.ShearStrengthRatioDeviation = properties.ShearStrengthRatioCoefficientOfVariation.Value;
+ soilLayer.ShearStrengthRatioCoefficientOfVariation = properties.ShearStrengthRatioCoefficientOfVariation.Value;
}
if (properties.StrengthIncreaseExponentDistribution.HasValue)
{
@@ -191,7 +191,7 @@
}
if (properties.StrengthIncreaseExponentCoefficientOfVariation.HasValue)
{
- soilLayer.StrengthIncreaseExponentDeviation = properties.StrengthIncreaseExponentCoefficientOfVariation.Value;
+ soilLayer.StrengthIncreaseExponentCoefficientOfVariation = properties.StrengthIncreaseExponentCoefficientOfVariation.Value;
}
if (properties.PopDistribution.HasValue)
{
@@ -207,7 +207,7 @@
}
if (properties.PopCoefficientOfVariation.HasValue)
{
- soilLayer.PopDeviation = properties.PopCoefficientOfVariation.Value;
+ soilLayer.PopCoefficientOfVariation = properties.PopCoefficientOfVariation.Value;
}
}
}
Index: Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerBaseTest.cs
===================================================================
diff -u -ra055d56e9d6e79c7285a51cce7de68188f252431 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerBaseTest.cs (.../SoilLayerBaseTest.cs) (revision a055d56e9d6e79c7285a51cce7de68188f252431)
+++ Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerBaseTest.cs (.../SoilLayerBaseTest.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -61,32 +61,32 @@
Assert.IsNull(layer.AbovePhreaticLevelDistribution);
Assert.IsNaN(layer.AbovePhreaticLevelMean);
- Assert.IsNaN(layer.AbovePhreaticLevelDeviation);
+ Assert.IsNaN(layer.AbovePhreaticLevelCoefficientOfVariation);
Assert.IsNaN(layer.AbovePhreaticLevelShift);
Assert.IsNull(layer.CohesionDistribution);
Assert.IsNaN(layer.CohesionMean);
- Assert.IsNaN(layer.CohesionDeviation);
+ Assert.IsNaN(layer.CohesionCoefficientOfVariation);
Assert.IsNaN(layer.CohesionShift);
Assert.IsNull(layer.FrictionAngleDistribution);
Assert.IsNaN(layer.FrictionAngleMean);
- Assert.IsNaN(layer.FrictionAngleDeviation);
+ Assert.IsNaN(layer.FrictionAngleCoefficientOfVariation);
Assert.IsNaN(layer.FrictionAngleShift);
Assert.IsNull(layer.ShearStrengthRatioDistribution);
Assert.IsNaN(layer.ShearStrengthRatioMean);
- Assert.IsNaN(layer.ShearStrengthRatioDeviation);
+ Assert.IsNaN(layer.ShearStrengthRatioCoefficientOfVariation);
Assert.IsNaN(layer.ShearStrengthRatioShift);
Assert.IsNull(layer.StrengthIncreaseExponentDistribution);
Assert.IsNaN(layer.StrengthIncreaseExponentMean);
- Assert.IsNaN(layer.StrengthIncreaseExponentDeviation);
+ Assert.IsNaN(layer.StrengthIncreaseExponentCoefficientOfVariation);
Assert.IsNaN(layer.StrengthIncreaseExponentShift);
Assert.IsNull(layer.PopDistribution);
Assert.IsNaN(layer.PopMean);
- Assert.IsNaN(layer.PopDeviation);
+ Assert.IsNaN(layer.PopCoefficientOfVariation);
Assert.IsNaN(layer.PopShift);
}
Index: Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerHelperTest.cs
===================================================================
diff -u -r738617f07027419f558043bd50caf8e53663dd0d -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerHelperTest.cs (.../SoilLayerHelperTest.cs) (revision 738617f07027419f558043bd50caf8e53663dd0d)
+++ Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilLayerHelperTest.cs (.../SoilLayerHelperTest.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -189,32 +189,32 @@
Assert.AreEqual(properties.ShearStrengthModel, soilLayer.ShearStrengthModel);
Assert.AreEqual(properties.AbovePhreaticLevelDistribution, soilLayer.AbovePhreaticLevelDistribution);
Assert.AreEqual(properties.AbovePhreaticLevelMean, soilLayer.AbovePhreaticLevelMean);
- Assert.AreEqual(properties.AbovePhreaticLevelCoefficientOfVariation, soilLayer.AbovePhreaticLevelDeviation);
+ Assert.AreEqual(properties.AbovePhreaticLevelCoefficientOfVariation, soilLayer.AbovePhreaticLevelCoefficientOfVariation);
Assert.AreEqual(properties.AbovePhreaticLevelShift, soilLayer.AbovePhreaticLevelShift);
Assert.AreEqual(properties.CohesionDistribution, soilLayer.CohesionDistribution);
Assert.AreEqual(properties.CohesionMean, soilLayer.CohesionMean);
- Assert.AreEqual(properties.CohesionCoefficientOfVariation, soilLayer.CohesionDeviation);
+ Assert.AreEqual(properties.CohesionCoefficientOfVariation, soilLayer.CohesionCoefficientOfVariation);
Assert.AreEqual(properties.CohesionShift, soilLayer.CohesionShift);
Assert.AreEqual(properties.FrictionAngleDistribution, soilLayer.FrictionAngleDistribution);
Assert.AreEqual(properties.FrictionAngleMean, soilLayer.FrictionAngleMean);
- Assert.AreEqual(properties.FrictionAngleCoefficientOfVariation, soilLayer.FrictionAngleDeviation);
+ Assert.AreEqual(properties.FrictionAngleCoefficientOfVariation, soilLayer.FrictionAngleCoefficientOfVariation);
Assert.AreEqual(properties.FrictionAngleShift, soilLayer.FrictionAngleShift);
Assert.AreEqual(properties.ShearStrengthRatioDistribution, soilLayer.ShearStrengthRatioDistribution);
Assert.AreEqual(properties.ShearStrengthRatioMean, soilLayer.ShearStrengthRatioMean);
- Assert.AreEqual(properties.ShearStrengthRatioCoefficientOfVariation, soilLayer.ShearStrengthRatioDeviation);
+ Assert.AreEqual(properties.ShearStrengthRatioCoefficientOfVariation, soilLayer.ShearStrengthRatioCoefficientOfVariation);
Assert.AreEqual(properties.ShearStrengthRatioShift, soilLayer.ShearStrengthRatioShift);
Assert.AreEqual(properties.StrengthIncreaseExponentDistribution, soilLayer.StrengthIncreaseExponentDistribution);
Assert.AreEqual(properties.StrengthIncreaseExponentMean, soilLayer.StrengthIncreaseExponentMean);
- Assert.AreEqual(properties.StrengthIncreaseExponentCoefficientOfVariation, soilLayer.StrengthIncreaseExponentDeviation);
+ Assert.AreEqual(properties.StrengthIncreaseExponentCoefficientOfVariation, soilLayer.StrengthIncreaseExponentCoefficientOfVariation);
Assert.AreEqual(properties.StrengthIncreaseExponentShift, soilLayer.StrengthIncreaseExponentShift);
Assert.AreEqual(properties.PopDistribution, soilLayer.PopDistribution);
Assert.AreEqual(properties.PopMean, soilLayer.PopMean);
- Assert.AreEqual(properties.PopCoefficientOfVariation, soilLayer.PopDeviation);
+ Assert.AreEqual(properties.PopCoefficientOfVariation, soilLayer.PopCoefficientOfVariation);
Assert.AreEqual(properties.PopShift, soilLayer.PopShift);
mockRepository.VerifyAll();
@@ -262,32 +262,32 @@
Assert.IsNull(soilLayer.AbovePhreaticLevelDistribution);
Assert.IsNaN(soilLayer.AbovePhreaticLevelMean);
- Assert.IsNaN(soilLayer.AbovePhreaticLevelDeviation);
+ Assert.IsNaN(soilLayer.AbovePhreaticLevelCoefficientOfVariation);
Assert.IsNaN(soilLayer.AbovePhreaticLevelShift);
Assert.IsNull(soilLayer.CohesionDistribution);
Assert.IsNaN(soilLayer.CohesionMean);
- Assert.IsNaN(soilLayer.CohesionDeviation);
+ Assert.IsNaN(soilLayer.CohesionCoefficientOfVariation);
Assert.IsNaN(soilLayer.CohesionShift);
Assert.IsNull(soilLayer.FrictionAngleDistribution);
Assert.IsNaN(soilLayer.FrictionAngleMean);
- Assert.IsNaN(soilLayer.FrictionAngleDeviation);
+ Assert.IsNaN(soilLayer.FrictionAngleCoefficientOfVariation);
Assert.IsNaN(soilLayer.FrictionAngleShift);
Assert.IsNull(soilLayer.ShearStrengthRatioDistribution);
Assert.IsNaN(soilLayer.ShearStrengthRatioMean);
- Assert.IsNaN(soilLayer.ShearStrengthRatioDeviation);
+ Assert.IsNaN(soilLayer.ShearStrengthRatioCoefficientOfVariation);
Assert.IsNaN(soilLayer.ShearStrengthRatioShift);
Assert.IsNull(soilLayer.StrengthIncreaseExponentDistribution);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentMean);
- Assert.IsNaN(soilLayer.StrengthIncreaseExponentDeviation);
+ Assert.IsNaN(soilLayer.StrengthIncreaseExponentCoefficientOfVariation);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentShift);
Assert.IsNull(soilLayer.PopDistribution);
Assert.IsNaN(soilLayer.PopMean);
- Assert.IsNaN(soilLayer.PopDeviation);
+ Assert.IsNaN(soilLayer.PopCoefficientOfVariation);
Assert.IsNaN(soilLayer.PopShift);
mockRepository.VerifyAll();
Index: Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs
===================================================================
diff -u -r0d2a68ed9f6d5c10c01a1cb7de3bdcba843d4ab8 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs (.../SoilProfile1DReaderTest.cs) (revision 0d2a68ed9f6d5c10c01a1cb7de3bdcba843d4ab8)
+++ Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile1DReaderTest.cs (.../SoilProfile1DReaderTest.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -436,7 +436,7 @@
0.01,
0.01,
0.01
- }, profile.Layers.Select(l => l.AbovePhreaticLevelDeviation));
+ }, profile.Layers.Select(l => l.AbovePhreaticLevelCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0,
@@ -465,7 +465,7 @@
0.09999999999999999,
0.1,
0.09999999999999999
- }, profile.Layers.Select(l => l.CohesionDeviation));
+ }, profile.Layers.Select(l => l.CohesionCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -494,7 +494,7 @@
0.01,
0.01,
0.01
- }, profile.Layers.Select(l => l.FrictionAngleDeviation));
+ }, profile.Layers.Select(l => l.FrictionAngleCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -523,7 +523,7 @@
0.011153846153846153,
0.004193548387096774,
0.029285714285714283
- }, profile.Layers.Select(l => l.ShearStrengthRatioDeviation));
+ }, profile.Layers.Select(l => l.ShearStrengthRatioCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.04,
@@ -552,7 +552,7 @@
0.09999999999999999,
0.1,
0.1
- }, profile.Layers.Select(l => l.StrengthIncreaseExponentDeviation));
+ }, profile.Layers.Select(l => l.StrengthIncreaseExponentCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -581,7 +581,7 @@
0.000990990990990991,
0.000990990990990991,
0.000990990990990991
- }, profile.Layers.Select(l => l.PopDeviation));
+ }, profile.Layers.Select(l => l.PopCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -636,32 +636,32 @@
Assert.IsNull(soilLayer.AbovePhreaticLevelDistribution);
Assert.IsNaN(soilLayer.AbovePhreaticLevelMean);
- Assert.IsNaN(soilLayer.AbovePhreaticLevelDeviation);
+ Assert.IsNaN(soilLayer.AbovePhreaticLevelCoefficientOfVariation);
Assert.IsNaN(soilLayer.AbovePhreaticLevelShift);
Assert.IsNull(soilLayer.CohesionDistribution);
Assert.IsNaN(soilLayer.CohesionMean);
- Assert.IsNaN(soilLayer.CohesionDeviation);
+ Assert.IsNaN(soilLayer.CohesionCoefficientOfVariation);
Assert.IsNaN(soilLayer.CohesionShift);
Assert.IsNull(soilLayer.FrictionAngleDistribution);
Assert.IsNaN(soilLayer.FrictionAngleMean);
- Assert.IsNaN(soilLayer.FrictionAngleDeviation);
+ Assert.IsNaN(soilLayer.FrictionAngleCoefficientOfVariation);
Assert.IsNaN(soilLayer.FrictionAngleShift);
Assert.IsNull(soilLayer.ShearStrengthRatioDistribution);
Assert.IsNaN(soilLayer.ShearStrengthRatioMean);
- Assert.IsNaN(soilLayer.ShearStrengthRatioDeviation);
+ Assert.IsNaN(soilLayer.ShearStrengthRatioCoefficientOfVariation);
Assert.IsNaN(soilLayer.ShearStrengthRatioShift);
Assert.IsNull(soilLayer.StrengthIncreaseExponentDistribution);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentMean);
- Assert.IsNaN(soilLayer.StrengthIncreaseExponentDeviation);
+ Assert.IsNaN(soilLayer.StrengthIncreaseExponentCoefficientOfVariation);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentShift);
Assert.IsNull(soilLayer.PopDistribution);
Assert.IsNaN(soilLayer.PopMean);
- Assert.IsNaN(soilLayer.PopDeviation);
+ Assert.IsNaN(soilLayer.PopCoefficientOfVariation);
Assert.IsNaN(soilLayer.PopShift);
}
Index: Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs
===================================================================
diff -u -rfb494de3c4b854048e775f41b2905860beedb3b5 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs (.../SoilProfile2DReaderTest.cs) (revision fb494de3c4b854048e775f41b2905860beedb3b5)
+++ Ringtoets/Common/test/Ringtoets.Common.IO.Test/SoilProfile/SoilProfile2DReaderTest.cs (.../SoilProfile2DReaderTest.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -280,7 +280,7 @@
0.01,
0,
0.01
- }, soilProfile2D.Layers.Select(l => l.AbovePhreaticLevelDeviation));
+ }, soilProfile2D.Layers.Select(l => l.AbovePhreaticLevelCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
10,
@@ -305,7 +305,7 @@
0.1,
0.09999999999999999,
0.09999999999999999
- }, soilProfile2D.Layers.Select(l => l.CohesionDeviation));
+ }, soilProfile2D.Layers.Select(l => l.CohesionCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -330,7 +330,7 @@
10,
0.01,
0.01
- }, soilProfile2D.Layers.Select(l => l.FrictionAngleDeviation));
+ }, soilProfile2D.Layers.Select(l => l.FrictionAngleCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0,
@@ -355,7 +355,7 @@
1,
0.029285714285714283,
0.011153846153846153
- }, soilProfile2D.Layers.Select(l => l.ShearStrengthRatioDeviation));
+ }, soilProfile2D.Layers.Select(l => l.ShearStrengthRatioCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
1,
@@ -380,7 +380,7 @@
1,
0.1,
0.09999999999999999
- }, soilProfile2D.Layers.Select(l => l.StrengthIncreaseExponentDeviation));
+ }, soilProfile2D.Layers.Select(l => l.StrengthIncreaseExponentCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0,
@@ -405,7 +405,7 @@
0.000990990990990991,
0.000990990990990991,
0.000990990990990991
- }, soilProfile2D.Layers.Select(l => l.PopDeviation));
+ }, soilProfile2D.Layers.Select(l => l.PopCoefficientOfVariation));
CollectionAssert.AreEqual(new[]
{
0.01,
@@ -459,32 +459,32 @@
Assert.IsNull(soilLayer.AbovePhreaticLevelDistribution);
Assert.IsNaN(soilLayer.AbovePhreaticLevelMean);
- Assert.IsNaN(soilLayer.AbovePhreaticLevelDeviation);
+ Assert.IsNaN(soilLayer.AbovePhreaticLevelCoefficientOfVariation);
Assert.IsNaN(soilLayer.AbovePhreaticLevelShift);
Assert.IsNull(soilLayer.CohesionDistribution);
Assert.IsNaN(soilLayer.CohesionMean);
- Assert.IsNaN(soilLayer.CohesionDeviation);
+ Assert.IsNaN(soilLayer.CohesionCoefficientOfVariation);
Assert.IsNaN(soilLayer.CohesionShift);
Assert.IsNull(soilLayer.FrictionAngleDistribution);
Assert.IsNaN(soilLayer.FrictionAngleMean);
- Assert.IsNaN(soilLayer.FrictionAngleDeviation);
+ Assert.IsNaN(soilLayer.FrictionAngleCoefficientOfVariation);
Assert.IsNaN(soilLayer.FrictionAngleShift);
Assert.IsNull(soilLayer.ShearStrengthRatioDistribution);
Assert.IsNaN(soilLayer.ShearStrengthRatioMean);
- Assert.IsNaN(soilLayer.ShearStrengthRatioDeviation);
+ Assert.IsNaN(soilLayer.ShearStrengthRatioCoefficientOfVariation);
Assert.IsNaN(soilLayer.ShearStrengthRatioShift);
Assert.IsNull(soilLayer.StrengthIncreaseExponentDistribution);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentMean);
- Assert.IsNaN(soilLayer.StrengthIncreaseExponentDeviation);
+ Assert.IsNaN(soilLayer.StrengthIncreaseExponentCoefficientOfVariation);
Assert.IsNaN(soilLayer.StrengthIncreaseExponentShift);
Assert.IsNull(soilLayer.PopDistribution);
Assert.IsNaN(soilLayer.PopMean);
- Assert.IsNaN(soilLayer.PopDeviation);
+ Assert.IsNaN(soilLayer.PopCoefficientOfVariation);
Assert.IsNaN(soilLayer.PopShift);
}
Index: Ringtoets/MacroStabilityInwards/src/Ringtoets.MacroStabilityInwards.IO/SoilProfiles/MacroStabilityInwardsSoilLayerTransformer.cs
===================================================================
diff -u -r91dfcac4a3eff0748168e9fc8e9400e209844363 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/MacroStabilityInwards/src/Ringtoets.MacroStabilityInwards.IO/SoilProfiles/MacroStabilityInwardsSoilLayerTransformer.cs (.../MacroStabilityInwardsSoilLayerTransformer.cs) (revision 91dfcac4a3eff0748168e9fc8e9400e209844363)
+++ Ringtoets/MacroStabilityInwards/src/Ringtoets.MacroStabilityInwards.IO/SoilProfiles/MacroStabilityInwardsSoilLayerTransformer.cs (.../MacroStabilityInwardsSoilLayerTransformer.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -113,19 +113,19 @@
properties.IsAquifer = soilLayer.IsAquifer;
properties.Color = soilLayer.Color;
properties.AbovePhreaticLevelMean = soilLayer.AbovePhreaticLevelMean;
- properties.AbovePhreaticLevelDeviation = soilLayer.AbovePhreaticLevelDeviation;
+ properties.AbovePhreaticLevelDeviation = soilLayer.AbovePhreaticLevelCoefficientOfVariation;
properties.BelowPhreaticLevelMean = soilLayer.BelowPhreaticLevelMean;
properties.BelowPhreaticLevelDeviation = soilLayer.BelowPhreaticLevelDeviation;
properties.CohesionMean = soilLayer.CohesionMean;
- properties.CohesionDeviation = soilLayer.CohesionDeviation;
+ properties.CohesionDeviation = soilLayer.CohesionCoefficientOfVariation;
properties.FrictionAngleMean = soilLayer.FrictionAngleMean;
- properties.FrictionAngleDeviation = soilLayer.FrictionAngleDeviation;
+ properties.FrictionAngleDeviation = soilLayer.FrictionAngleCoefficientOfVariation;
properties.ShearStrengthRatioMean = soilLayer.ShearStrengthRatioMean;
- properties.ShearStrengthRatioDeviation = soilLayer.ShearStrengthRatioDeviation;
+ properties.ShearStrengthRatioDeviation = soilLayer.ShearStrengthRatioCoefficientOfVariation;
properties.StrengthIncreaseExponentMean = soilLayer.StrengthIncreaseExponentMean;
- properties.StrengthIncreaseExponentDeviation = soilLayer.StrengthIncreaseExponentDeviation;
+ properties.StrengthIncreaseExponentDeviation = soilLayer.StrengthIncreaseExponentCoefficientOfVariation;
properties.PopMean = soilLayer.PopMean;
- properties.PopDeviation = soilLayer.PopDeviation;
+ properties.PopDeviation = soilLayer.PopCoefficientOfVariation;
}
private static bool TransformUsePop(double? usePop)
Index: Ringtoets/MacroStabilityInwards/test/Ringtoets.MacroStabilityInwards.IO.Test/SoilProfiles/MacroStabilityInwardsSoilLayerTransformerTest.cs
===================================================================
diff -u -rdf936be59da19d844148f0048b03a52c3aa9d1b7 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/MacroStabilityInwards/test/Ringtoets.MacroStabilityInwards.IO.Test/SoilProfiles/MacroStabilityInwardsSoilLayerTransformerTest.cs (.../MacroStabilityInwardsSoilLayerTransformerTest.cs) (revision df936be59da19d844148f0048b03a52c3aa9d1b7)
+++ Ringtoets/MacroStabilityInwards/test/Ringtoets.MacroStabilityInwards.IO.Test/SoilProfiles/MacroStabilityInwardsSoilLayerTransformerTest.cs (.../MacroStabilityInwardsSoilLayerTransformerTest.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -80,19 +80,19 @@
MaterialName = materialName,
Color = color,
AbovePhreaticLevelMean = abovePhreaticLevelMean,
- AbovePhreaticLevelDeviation = abovePhreaticLevelDeviation,
+ AbovePhreaticLevelCoefficientOfVariation = abovePhreaticLevelDeviation,
BelowPhreaticLevelMean = belowPhreaticLevelMean,
BelowPhreaticLevelDeviation = belowPhreaticLevelDeviation,
CohesionMean = cohesionMean,
- CohesionDeviation = cohesionDeviation,
+ CohesionCoefficientOfVariation = cohesionDeviation,
FrictionAngleMean = frictionAngleMean,
- FrictionAngleDeviation = frictionAngleDeviation,
+ FrictionAngleCoefficientOfVariation = frictionAngleDeviation,
ShearStrengthRatioMean = shearStrengthRatioMean,
- ShearStrengthRatioDeviation = shearStrengthRatioDeviation,
+ ShearStrengthRatioCoefficientOfVariation = shearStrengthRatioDeviation,
StrengthIncreaseExponentMean = strengthIncreaseExponentMean,
- StrengthIncreaseExponentDeviation = strengthIncreaseExponentDeviation,
+ StrengthIncreaseExponentCoefficientOfVariation = strengthIncreaseExponentDeviation,
PopMean = popMean,
- PopDeviation = popDeviation
+ PopCoefficientOfVariation = popDeviation
};
// Call
@@ -264,19 +264,19 @@
layer.MaterialName = materialName;
layer.Color = color;
layer.AbovePhreaticLevelMean = abovePhreaticLevelMean;
- layer.AbovePhreaticLevelDeviation = abovePhreaticLevelDeviation;
+ layer.AbovePhreaticLevelCoefficientOfVariation = abovePhreaticLevelDeviation;
layer.BelowPhreaticLevelMean = belowPhreaticLevelMean;
layer.BelowPhreaticLevelDeviation = belowPhreaticLevelDeviation;
layer.CohesionMean = cohesionMean;
- layer.CohesionDeviation = cohesionDeviation;
+ layer.CohesionCoefficientOfVariation = cohesionDeviation;
layer.FrictionAngleMean = frictionAngleMean;
- layer.FrictionAngleDeviation = frictionAngleDeviation;
+ layer.FrictionAngleCoefficientOfVariation = frictionAngleDeviation;
layer.ShearStrengthRatioMean = shearStrengthRatioMean;
- layer.ShearStrengthRatioDeviation = shearStrengthRatioDeviation;
+ layer.ShearStrengthRatioCoefficientOfVariation = shearStrengthRatioDeviation;
layer.StrengthIncreaseExponentMean = strengthIncreaseExponentMean;
- layer.StrengthIncreaseExponentDeviation = strengthIncreaseExponentDeviation;
+ layer.StrengthIncreaseExponentCoefficientOfVariation = strengthIncreaseExponentDeviation;
layer.PopMean = popMean;
- layer.PopDeviation = popDeviation;
+ layer.PopCoefficientOfVariation = popDeviation;
// Call
MacroStabilityInwardsSoilLayer2D soilLayer2D = MacroStabilityInwardsSoilLayerTransformer.Transform(layer);
Index: Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerBase.cs
===================================================================
diff -u -r1cc75d1898d59583d1f714e577490768e9574652 -re14d435cf9328ecd215e94bd3a34f126b2885e6d
--- Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerBase.cs (.../SoilLayerBase.cs) (revision 1cc75d1898d59583d1f714e577490768e9574652)
+++ Ringtoets/Common/src/Ringtoets.Common.IO/SoilProfile/SoilLayerBase.cs (.../SoilLayerBase.cs) (revision e14d435cf9328ecd215e94bd3a34f126b2885e6d)
@@ -51,27 +51,27 @@
PermeabilityShift = double.NaN;
AbovePhreaticLevelMean = double.NaN;
- AbovePhreaticLevelDeviation = double.NaN;
+ AbovePhreaticLevelCoefficientOfVariation = double.NaN;
AbovePhreaticLevelShift = double.NaN;
CohesionMean = double.NaN;
- CohesionDeviation = double.NaN;
+ CohesionCoefficientOfVariation = double.NaN;
CohesionShift = double.NaN;
FrictionAngleMean = double.NaN;
- FrictionAngleDeviation = double.NaN;
+ FrictionAngleCoefficientOfVariation = double.NaN;
FrictionAngleShift = double.NaN;
ShearStrengthRatioMean = double.NaN;
- ShearStrengthRatioDeviation = double.NaN;
+ ShearStrengthRatioCoefficientOfVariation = double.NaN;
ShearStrengthRatioShift = double.NaN;
StrengthIncreaseExponentMean = double.NaN;
- StrengthIncreaseExponentDeviation = double.NaN;
+ StrengthIncreaseExponentCoefficientOfVariation = double.NaN;
StrengthIncreaseExponentShift = double.NaN;
PopMean = double.NaN;
- PopDeviation = double.NaN;
+ PopCoefficientOfVariation = double.NaN;
PopShift = double.NaN;
}
@@ -207,17 +207,17 @@
public double AbovePhreaticLevelMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the volumic weight of the layer above the phreatic level.
/// [kN/m³]
///
- public double AbovePhreaticLevelDeviation { get; set; }
+ public double AbovePhreaticLevelCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the volumic weight of the layer above the phreatic level.
/// [kN/m³]
///
public double AbovePhreaticLevelShift { get; set; }
-
+
///
/// Gets or sets the distribution for the cohesion.
/// [kN/m³]
@@ -231,10 +231,10 @@
public double CohesionMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the cohesion.
/// [kN/m³]
///
- public double CohesionDeviation { get; set; }
+ public double CohesionCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the cohesion.
@@ -255,10 +255,10 @@
public double FrictionAngleMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the friction angle.
/// [°]
///
- public double FrictionAngleDeviation { get; set; }
+ public double FrictionAngleCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the friction angle.
@@ -279,10 +279,10 @@
public double ShearStrengthRatioMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the ratio of shear strength S.
/// [-]
///
- public double ShearStrengthRatioDeviation { get; set; }
+ public double ShearStrengthRatioCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the ratio of shear strength S.
@@ -303,10 +303,10 @@
public double StrengthIncreaseExponentMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the strength increase exponent (m).
/// [-]
///
- public double StrengthIncreaseExponentDeviation { get; set; }
+ public double StrengthIncreaseExponentCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the strength increase exponent (m).
@@ -327,10 +327,10 @@
public double PopMean { get; set; }
///
/// Gets or sets the deviation of the distribution for the POP.
/// [kN/m²]
///
- public double PopDeviation { get; set; }
+ public double PopCoefficientOfVariation { get; set; }
///
/// Gets or sets the shift of the distribution for the POP.
@@ -207,17 +207,17 @@
public double AbovePhreaticLevelMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the volumic weight of the layer above the phreatic level.
+ /// Gets or sets the coefficient of variation of the distribution for the volumic weight of the layer above the phreatic level.
/// [kN/m³]
///
@@ -231,10 +231,10 @@
public double CohesionMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the cohesion.
+ /// Gets or sets the coefficient of variation of the distribution for the cohesion.
/// [kN/m³]
///
@@ -255,10 +255,10 @@
public double FrictionAngleMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the friction angle.
+ /// Gets or sets the coefficient of variation of the distribution for the friction angle.
/// [°]
///
@@ -279,10 +279,10 @@
public double ShearStrengthRatioMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the ratio of shear strength S.
+ /// Gets or sets the coefficient of variation of the distribution for the ratio of shear strength S.
/// [-]
///
@@ -303,10 +303,10 @@
public double StrengthIncreaseExponentMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the strength increase exponent (m).
+ /// Gets or sets the coefficient of variation of the distribution for the strength increase exponent (m).
/// [-]
///
@@ -327,10 +327,10 @@
public double PopMean { get; set; }
///
- /// Gets or sets the deviation of the distribution for the POP.
+ /// Gets or sets the coefficient of variation of the distribution for the POP.
/// [kN/m²]
///